@@ -43,7 +43,11 @@ class R3sponse(object):
 		for key, value in variables.items():
 			response[key] = value
 		r3sponse.log(message=response["message"], log_level=log_level, save=save)
-		if django: response = JsonResponse(response.dict(), safe=False)
+		if django: 
+			try:
+				response = JsonResponse(response.dict(), safe=False)
+			except:
+				response = JsonResponse(response, safe=False)
 		return response
 	def error_response(self,
 		# the error message.
@@ -60,7 +64,11 @@ class R3sponse(object):
 		response["message"] = None
 		response["error"] = error
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
-		if django: response = JsonResponse(response.dict(), safe=False)
+		if django: 
+			try:
+				response = JsonResponse(response.dict(), safe=False)
+			except:
+				response = JsonResponse(response, safe=False)
 		return response
 		#
 	def success(self, response):
@@ -93,13 +101,17 @@ class R3sponse(object):
 			elif format in ["array", "list"]: variable = variable.split(",")
 			else:
 				raise ValueError(f"Unrecognized <r3sponse.get_request_parameter> format: {format}.")
-		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].")
+		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].", {
+			"key":identifier,
+			"value":variable,
+		})
 	def get_request_parameters(self, request, identifiers=[], optional=False, empty_value=None):
 		if isinstance(identifiers, str):
 			return self.error_response("__get_request_params__ is used to retrieve several identifiers (array format not string).")
 		params = ResponseObject()
 		for param in identifiers:
 			param_value, response = self.get_request_parameter(request, param)
+			param = param.split(":")[0]
 			if response["error"] != None: 
 				if optional:
 					params[param] = empty_value
@@ -240,10 +252,13 @@ class ResponseObject(object):
 		return list(vars(self).keys())
 	def values(self):
 		return list(vars(self).values())
-	def dict(self):
+	def dict(self, serializable=False):
 		dictionary = {}
 		for key, value in self.items():
-			dictionary[key] = value
+			if isinstance(value, object):
+				dictionary[key] = str(value)
+			else:
+				dictionary[key] = value
 		return dictionary
 	# assign self variables by dictionary.
 	def assign(self, dictionary):
@@ -270,6 +285,10 @@ class ResponseObject(object):
 	# string format.
 	def __str__(self):
 		return json.dumps(self.dict(), indent=4)
+		if isinstance(self, dict):
+			return json.dumps(self, indent=4)
+		else:
+			return json.dumps(self.dict(), indent=4)
 	def json(self,):
 		return json.dumps(self, default=lambda o: o.__dict__)
 	#def __dict__(self):
